@@ -60,7 +60,7 @@ class FormErrors(t.Mapping):
             'field_errors': self.field_errors,
         }
 
-    def keys(self) -> t.AbstractSet[str]:
+    def keys(self) -> t.KeysView[str]:
         return self.field_errors.keys()
 
     def __bool__(self) -> bool:
@@ -160,7 +160,7 @@ class Request(requests.Request):
     def __new__(cls, scope: Scope, receive: Receive = empty_receive, send: Send = empty_send) -> Request:
         if 'request' not in scope:
             instance = super().__new__(cls)
-            instance.__init__(scope, receive, send)
+            instance.__init__(scope, receive, send)  # type: ignore
             scope['request'] = instance
         elif scope['request'].__class__ != cls:
             # view function uses custom request class
@@ -192,6 +192,10 @@ class Request(requests.Request):
         with 'application/json' value."""
         return "application/json" in self.headers.get("accept", "")
 
+    @property
+    def is_json(self) -> bool:
+        return "application/json" in self.headers.get("content-type", "")
+
     @property
     def is_xhr(self) -> bool:
         """
@@ -284,5 +288,12 @@ class Request(requests.Request):
         data = await self.form()
         return FilesData(FormData([(k, v) for k, v in data.multi_items() if isinstance(v, UploadFile)]))
 
+    async def data(self) -> t.Mapping:
+        """Returns a request data.
+        Automatically decodes JSON if Content-Type is application/json."""
+        if self.is_json:
+            return await self.json()
+        return await self.form()
+
     def __repr__(self) -> str:
         return f'<{self.__class__.__name__}: {self.method} {self.url}>'
